@@ -1,20 +1,23 @@
 # CHILDES XML Corpus Reader
 
-# Copyright (C) 2001-2012 NLTK Project
+# Copyright (C) 2001-2015 NLTK Project
 # Author: Tomonori Nagano <tnagano@gc.cuny.edu>
 #         Alexis Dimitriadis <A.Dimitriadis@uu.nl>
-# URL: <http://www.nltk.org/>
+# URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
 Corpus reader for the XML version of the CHILDES corpus.
 """
+from __future__ import print_function
+
 __docformat__ = 'epytext en'
 
 import re
 from collections import defaultdict
 
 from nltk.util import flatten
+from nltk.compat import string_types
 
 from nltk.corpus.reader.util import concat
 from nltk.corpus.reader.xmldocs import XMLCorpusReader, ElementTree
@@ -193,7 +196,7 @@ class CHILDESCorpusReader(XMLCorpusReader):
                         age = self.convert_age(age)
                     return age
             # some files don't have age data
-            except (TypeError, AttributeError), e:
+            except (TypeError, AttributeError) as e:
                 return None
 
     def convert_age(self, age_year):
@@ -204,7 +207,7 @@ class CHILDESCorpusReader(XMLCorpusReader):
             if int(m.group(3)) > 15:
                 age_month += 1
         # some corpora don't have age information?
-        except ValueError, e:
+        except ValueError as e:
             pass
         return age_month
 
@@ -257,7 +260,7 @@ class CHILDESCorpusReader(XMLCorpusReader):
 
     def _get_words(self, fileid, speaker, sent, stem, relation, pos,
             strip_space, replace):
-        if isinstance(speaker, str) and speaker != 'ALL':  # ensure we have a list of speakers
+        if isinstance(speaker, string_types) and speaker != 'ALL':  # ensure we have a list of speakers
             speaker = [ speaker ]
         xmldoc = ElementTree.parse(fileid).getroot()
         # processing each xml doc
@@ -288,7 +291,7 @@ class CHILDESCorpusReader(XMLCorpusReader):
                         try:
                             xmlstem = xmlword.find('.//{%s}stem' % NS)
                             word = xmlstem.text
-                        except AttributeError, e:
+                        except AttributeError as e:
                             pass
                         # if there is an inflection
                         try:
@@ -308,10 +311,13 @@ class CHILDESCorpusReader(XMLCorpusReader):
                     if relation or pos:
                         try:
                             xmlpos = xmlword.findall(".//{%s}c" % NS)
-                            word = (word,xmlpos[0].text)
-                            if len(xmlpos) != 1 and suffixStem:
-                                suffixStem = (suffixStem,xmlpos[1].text)
-                        except (AttributeError,IndexError), e:
+                            xmlpos2 = xmlword.findall(".//{%s}s" % NS)
+                            if xmlpos2 != []:
+                                tag = xmlpos[0].text+":"+xmlpos2[0].text
+                            else:
+                                tag = xmlpos[0].text
+                            word = (word,tag)
+                        except (AttributeError,IndexError) as e:
                             word = (word,None)
                             if suffixStem:
                                 suffixStem = (suffixStem,None)
@@ -416,7 +422,7 @@ class CHILDESCorpusReader(XMLCorpusReader):
         url = self.childes_url_base + path
 
         webbrowser.open_new_tab(url)
-        print "Opening in browser:", url
+        print("Opening in browser:", url)
         # Pausing is a good idea, but it's up to the user...
         # raw_input("Hit Return to continue")
 
@@ -432,7 +438,7 @@ def demo(corpus_root=None):
         corpus_root = find('corpora/childes/data-xml/Eng-USA/')
 
     try:
-        childes = CHILDESCorpusReader(corpus_root, u'.*.xml')
+        childes = CHILDESCorpusReader(corpus_root, '.*.xml')
         # describe all corpus
         for file in childes.fileids()[:5]:
             corpus = ''
@@ -440,32 +446,32 @@ def demo(corpus_root=None):
             for (key,value) in childes.corpus(file)[0].items():
                 if key == "Corpus": corpus = value
                 if key == "Id": corpus_id = value
-            print 'Reading', corpus,corpus_id,' .....'
-            print "words:", childes.words(file)[:7],"..."
-            print "words with replaced words:", childes.words(file, replace=True)[:7]," ..."
-            print "words with pos tags:", childes.tagged_words(file)[:7]," ..."
-            print "words (only MOT):", childes.words(file, speaker='MOT')[:7], "..."
-            print "words (only CHI):", childes.words(file, speaker='CHI')[:7], "..."
-            print "stemmed words:", childes.words(file, stem=True)[:7]," ..."
-            print "words with relations and pos-tag:", childes.words(file, relation=True)[:5]," ..."
-            print "sentence:", childes.sents(file)[:2]," ..."
+            print('Reading', corpus,corpus_id,' .....')
+            print("words:", childes.words(file)[:7],"...")
+            print("words with replaced words:", childes.words(file, replace=True)[:7]," ...")
+            print("words with pos tags:", childes.tagged_words(file)[:7]," ...")
+            print("words (only MOT):", childes.words(file, speaker='MOT')[:7], "...")
+            print("words (only CHI):", childes.words(file, speaker='CHI')[:7], "...")
+            print("stemmed words:", childes.words(file, stem=True)[:7]," ...")
+            print("words with relations and pos-tag:", childes.words(file, relation=True)[:5]," ...")
+            print("sentence:", childes.sents(file)[:2]," ...")
             for (participant, values) in childes.participants(file)[0].items():
                     for (key, value) in values.items():
-                        print "\tparticipant", participant, key, ":", value
-            print "num of sent:", len(childes.sents(file))
-            print "num of morphemes:", len(childes.words(file, stem=True))
-            print "age:", childes.age(file)
-            print "age in month:", childes.age(file, month=True)
-            print "MLU:", childes.MLU(file)
-            print
+                        print("\tparticipant", participant, key, ":", value)
+            print("num of sent:", len(childes.sents(file)))
+            print("num of morphemes:", len(childes.words(file, stem=True)))
+            print("age:", childes.age(file))
+            print("age in month:", childes.age(file, month=True))
+            print("MLU:", childes.MLU(file))
+            print()
 
-    except LookupError, e:
-        print """The CHILDES corpus, or the parts you need, should be manually
+    except LookupError as e:
+        print("""The CHILDES corpus, or the parts you need, should be manually
         downloaded from http://childes.psy.cmu.edu/data-xml/ and saved at
         [NLTK_Data_Dir]/corpora/childes/
             Alternately, you can call the demo with the path to a portion of the CHILDES corpus, e.g.:
         demo('/path/to/childes/data-xml/Eng-USA/")
-        """
+        """)
         #corpus_root_http = urllib2.urlopen('http://childes.psy.cmu.edu/data-xml/Eng-USA/Bates.zip')
         #corpus_root_http_bates = zipfile.ZipFile(cStringIO.StringIO(corpus_root_http.read()))
         ##this fails
